@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.92 2008/10/05 18:39:46 bowkenken Exp $
+* $Id: call.cpp,v 1.108 2009/07/25 20:47:15 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -157,6 +157,26 @@ void	call_gui_map_cont_exec_set( bool_t flagExec )
 #endif // D_GTK
 }
 
+/***************************************************************
+* ơС˥ҥȤɽ
+***************************************************************/
+
+void	call_gui_map_print_stat_bar_hint( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	guiMapPrintStatBarHint();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ˥塼ɥ
 * draw_menu_t *data : ˥塼ѥǡ
@@ -205,7 +225,6 @@ void	call_gui_menu_wipe( void )
 
 void	call_set_mouse_dflt_menu( long sel_n )
 {
-#ifndef D_MFC
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
@@ -218,7 +237,6 @@ void	call_set_mouse_dflt_menu( long sel_n )
 
 	gui_end();
 #endif
-#endif // ! D_MFC
 }
 
 /***************************************************************
@@ -266,7 +284,9 @@ void	call_gui_message_draw( void )
 * ϥɥ
 ***************************************************************/
 
-void	call_gui_num_draw( long *n, long min, long max, long figure )
+void	call_gui_num_draw(
+	volatile long *n, long min, long max, long figure
+)
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -346,10 +366,11 @@ void	call_gui_input_string_wipe( void )
 
 /***************************************************************
 * 쥦ɥ
+* const char *name : ̾
 * const char *str : 
 ***************************************************************/
 
-void	call_gui_words_draw( const char *str )
+void	call_gui_words_draw( const char *name, const char *str )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -359,7 +380,7 @@ void	call_gui_words_draw( const char *str )
 
 	gui_begin();
 
-	gGuiWords.draw( str );
+	gGuiWords.draw( name, str );
 
 	gui_end();
 #endif
@@ -367,11 +388,15 @@ void	call_gui_words_draw( const char *str )
 
 /***************************************************************
 * 쥦ɥ (ɽ)
+* const char *name : ̾
 * const char *str : 
 * long w : ɽ
 ***************************************************************/
 
-void	call_gui_words_draw_width( const char *str, long w )
+void	call_gui_words_draw_width(
+	const char *name, const char *str,
+	long w
+)
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -381,7 +406,7 @@ void	call_gui_words_draw_width( const char *str, long w )
 
 	gui_begin();
 
-	gGuiWords.draw( str, w );
+	gGuiWords.draw( name, str, w );
 
 	gui_end();
 #endif
@@ -489,6 +514,7 @@ void	call_gui_replay_wipe( void )
 
 /***************************************************************
 * 饹ǥɥ
+* class_t *p : 饹
 ***************************************************************/
 
 void	call_gui_class_edit_draw( class_t *p )
@@ -527,6 +553,47 @@ void	call_gui_class_edit_wipe( void )
 #endif
 }
 
+/***************************************************************
+* 롦ǥɥ
+* class_t *p : 饹
+***************************************************************/
+
+void	call_gui_skill_edit_draw( class_t *p )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiSkillEdit.draw( p );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 롦ǥɥĤ
+***************************************************************/
+
+void	call_gui_skill_edit_wipe( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiSkillEdit.wipe();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * 饯ȡɥ
 ***************************************************************/
@@ -549,6 +616,8 @@ void	call_gui_chr_sheet_draw( mbr_t *org, mbr_t *mbr )
 
 /***************************************************************
 * 饯ȡɥ
+* mbr_t *org : Υ饯ǡ
+* mbr_t *mbr : ԽΥ饯ǡ
 ***************************************************************/
 
 void	call_gui_chr_sheet_redraw( mbr_t *org, mbr_t *mbr )
@@ -686,7 +755,8 @@ bool_t	call_sel_mbr_graph_begin( mbr_t *mbr )
 
 	gui_begin();
 
-	gSelMbrGraph = new SelMbrGraph;
+	if( gSelMbrGraph == NULL )
+		gSelMbrGraph = new SelMbrGraph;
 	flgWait = gSelMbrGraph->exec( mbr );
 
 	gui_end();
@@ -713,6 +783,7 @@ void	call_sel_mbr_graph_end( void )
 	gui_begin();
 
 	delete gSelMbrGraph;
+	gSelMbrGraph = NULL;
 
 	gui_end();
 #endif
@@ -886,13 +957,31 @@ void	call_pcg_dun_draw(
 #endif // D_MFC
 }
 
+/***************************************************************
+* XX ιǡ
+* xx_act_kind_t kind : μ
+* void *p : Υǡ
+***************************************************************/
+
+void	call_pcg_dun_set_xx_attack(
+	long kind, void *p )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gPcgDun.setXxAttack( (xx_act_kind_t)kind, p );
+#endif
+}
+
 /***************************************************************
 * ƥȡ⡼ɤλޥåפʸ
 * long scrn_x : X ɸ
 * long scrn_y : Y ɸ
 * const char *s : եޥåʸ
 * ... : եޥåȤΰ
-* return : 顼̵ä
 ***************************************************************/
 
 void	call_pcg_dun_draw_string(
@@ -901,10 +990,11 @@ void	call_pcg_dun_draw_string(
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	va_list	argptr;
-	static char	buf[SCREEN_WIDTH * 2 + 1];
+	static char	buf[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
 
 	va_start( argptr, s );
-	vsn_printf( buf, SCREEN_WIDTH * 2, s, argptr );
+	vsn_printf( buf, max_len, s, argptr );
 	va_end( argptr );
 
 	if( !g_flg_init )
@@ -920,6 +1010,32 @@ void	call_pcg_dun_draw_string(
 #endif
 }
 
+/***************************************************************
+* VFX 
+* long scrn_x : X ɸ
+* long scrn_y : Y ɸ
+* long scrn_w : 
+* long scrn_h : ⤵
+***************************************************************/
+
+void	call_pcg_dun_draw_vfx(
+	long scrn_x, long scrn_y,
+	long scrn_w, long scrn_h )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gPcgDun.drawVfx( scrn_x, scrn_y, scrn_w, scrn_h, false );
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ޥåפΥ
 * long map_x : ޥåפ X ɸ
@@ -942,10 +1058,41 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 #endif
 }
 
+/***************************************************************
+* 롦ѥ֤
+* bool_t flagSub : ֡뤫?
+* return : 
+***************************************************************/
+
+long	call_pcg_dun_get_crsr_width( bool_t flagSub )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gPcgDun.getCrsrWidth( !!flagSub );
+#endif
+
+	return 0;
+}
+
+/***************************************************************
+* 롦ѥι⤵֤
+* bool_t flagSub : ֡뤫?
+* return : ⤵
+***************************************************************/
+
+long	call_pcg_dun_get_crsr_height( bool_t flagSub )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gPcgDun.getCrsrHeight( !!flagSub );
+#endif
+
+	return 0;
+}
+
 /***************************************************************
 * 饯κüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
@@ -982,6 +1129,7 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 * 饯αüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
@@ -1018,6 +1166,7 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 * 饯ξüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
@@ -1054,6 +1203,7 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 * 饯βüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
@@ -1140,6 +1290,11 @@ bool_t	call_pcg_dun_clip_win_y( long mapY )
 void	call_demo_last_boss_reset( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
 	if( gPcgDun.pDemoLastBoss == NULL )
 		return;
 
@@ -1155,6 +1310,11 @@ void	call_demo_last_boss_reset( void )
 bool_t	call_demo_last_boss_check_done( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return TRUE;
+	if( !g_flg_gui )
+		return TRUE;
+
 	if( gPcgDun.pDemoLastBoss == NULL )
 		return TRUE;
 
@@ -1169,12 +1329,19 @@ bool_t	call_demo_last_boss_check_done( void )
 
 /***************************************************************
 * ˹礻 BGM κ
+* bool_t flg_gui : GUI ƤФ줿?
 ***************************************************************/
 
-void	call_game_music_play_scene( void )
+void	call_game_music_play_scene( bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !flg_gui )
+		gui_begin();
+
 	gMusic.playScene();
+
+	if( !flg_gui )
+		gui_end();
 #endif
 }
 
@@ -1187,7 +1354,58 @@ void	call_game_music_play_scene( void )
 void	call_game_music_play( long kind, long idx )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gMusic.play( (music_kind_t)kind, idx );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* BGM κƺ
+***************************************************************/
+
+void	call_game_music_replay( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
+	gMusic.replay();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* SE κ
+* sound_kind_t kind : SE μ
+* long n : 
+***************************************************************/
+
+void	call_game_sound_play( long kind, long n )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
+	gSound.play( (sound_kind_t)kind, n );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* SE 
+***************************************************************/
+
+void	call_game_sound_stop( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
+	gSound.stop();
+
+	gui_end();
 #endif
 }
 
@@ -1199,7 +1417,17 @@ void	call_game_music_play( long kind, long idx )
 long	call_game_joystick_get_joy( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getJoy();
+	{
+		long	n;
+
+		gui_begin();
+
+		n = gJoystick.getJoy();
+
+		gui_end();
+
+		return n;
+	}
 #endif
 
 	return g_joy_n;
@@ -1213,7 +1441,11 @@ long	call_game_joystick_get_joy( void )
 void	call_game_joystick_sel_joy( long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gJoystick.selJoy( n );
+
+	gui_end();
 #endif
 
 	g_joy_n = n;
@@ -1228,7 +1460,17 @@ void	call_game_joystick_sel_joy( long n )
 const char	*call_game_joystick_get_name( long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getName( n );
+	{
+		const char	*s;
+
+		gui_begin();
+
+		s = gJoystick.getName( n );
+
+		gui_end();
+
+		return s;
+	}
 #endif
 
 	return NULL;
@@ -1242,7 +1484,17 @@ const char	*call_game_joystick_get_name( long n )
 long	call_game_joystick_get_kind( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getKind();
+	{
+		long	n;
+
+		gui_begin();
+
+		n = gJoystick.getKind();
+
+		gui_end();
+
+		return n;
+	}
 #endif
 
 	return g_joy_kind;
@@ -1256,7 +1508,11 @@ long	call_game_joystick_get_kind( void )
 void	call_game_joystick_set_kind( long kind )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gJoystick.setKind( (joy_kind_t)kind );
+
+	gui_end();
 #endif
 
 	g_joy_kind = (joy_kind_t)kind;
@@ -1424,6 +1680,26 @@ long	call_key_get_char( void )
 	return '\0';
 }
 
+/***************************************************************
+* 뤬ư˥ޥåפ򥹥뤹
+***************************************************************/
+
+void	call_key_check_move_crsr( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gKey.CheckMoveCrsr();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ϤΥ
 * long n :  (ߥ)
