@@ -49,6 +49,7 @@ bool_t	set_fx_polymorph( fx_t *fx );
 bool_t	clr_fx_polymorph( fx_t *fx );
 bool_t	cancel_fx_vanish( chr_t *chr );
 void	exec_fx_poison( fx_t *fx );
+void	exec_fx_fear( fx_t *fx );
 void	exec_fx_weak( fx_t *fx );
 void	exec_fx_store_light( fx_t *fx );
 modifier_t	*get_modifier_song_mbr( void );
@@ -297,6 +298,7 @@ void	free_fx( fx_t *p );
 void	free_fx_all( fx_t *p );
 void	ins_ls_fx( fx_t *ls, fx_t *p );
 fx_t	*srch_fx( fx_t *ls, fx_kind_t kind );
+void	check_memory_fx_c( void );
 
 #ifdef __cplusplus
 }
