@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.23 2008/05/18 19:49:18 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.33 2009/06/23 02:02:35 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -43,7 +43,28 @@
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
+* 
+* 󥫡ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* 󥫡 SQUARE_DIR_NORTH ǡ롣
+***************************************************************/
+
+square_dir_t	g_square_dir_trans_tab[] = {
+	SQUARE_DIR_NORTH,
+	SQUARE_DIR_EAST,
+	SQUARE_DIR_SOUTH,
+	SQUARE_DIR_WEST,
+
+	/* ɲ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 饯μɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -55,13 +76,15 @@ chr_kind_t	g_chr_trans_tab[] = {
 	CHR_KIND_NULL,
 	CHR_KIND_MBR,	/* С(PC) */
 	CHR_KIND_MNSTR,	/* 󥹥 */
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ²ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -75,13 +98,15 @@ main_race_t	g_main_race_trans_tab[] = {
 	MAIN_RACE_ELF,
 	MAIN_RACE_DWARF,
 	MAIN_RACE_VIVID,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ²ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -99,13 +124,15 @@ sub_race_t	g_sub_race_trans_tab[] = {
 	SUB_RACE_PIG,
 	SUB_RACE_BIRD,
 	SUB_RACE_LIZARD,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ̤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -121,13 +148,106 @@ sex_t	g_sex_trans_tab[] = {
 
 	/*  */
 	MALE,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
+* 
+* ǽͤɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ǽͤ ABL_KIND_MAX_N ǡ롣
+***************************************************************/
+
+abl_kind_t	g_abl_trans_tab[] = {
+	ABL_KIND_HP,
+	ABL_KIND_MP,
+	ABL_KIND_DEX,
+	ABL_KIND_STR,
+	ABL_KIND_AGI,
+	ABL_KIND_INT,
+	ABL_KIND_WIS,
+	ABL_KIND_CHA,
+	ABL_KIND_FIG,
+	ABL_KIND_MON,
+	ABL_KIND_HUN,
+	ABL_KIND_THI,
+	ABL_KIND_MAG,
+	ABL_KIND_SOR,
+	ABL_KIND_ENC,
+	ABL_KIND_SUM,
+	ABL_KIND_PRI,
+	ABL_KIND_SHA,
+	ABL_KIND_BAR,
+	ABL_KIND_NIN,
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_NULL),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_ATTACKER),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_BERSERKER),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DEFENDER),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_SENTINEL),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_ASSASSIN),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_AEGIS),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_SIEGE),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_PHALANX),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DOUBLE_ATTACK),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_COMBO),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RAPID_SHOOT),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_COUNTER),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_TWO_SWORD_FENCING),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_KNOC),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_SLAS),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_STIN),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_HEAT),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_COLD),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_MIND),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_ACID),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_ELEC),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DAM_POIS),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_KNOC),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_SLAS),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_STIN),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_HEAT),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_COLD),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_MIND),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_ACID),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_ELEC),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RESI_POIS),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_DEAD),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_STONE),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_PARALYZE),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_POISON),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_CONFUSION),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_BLIND),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_SLEEP),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_SILENCE),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_CAUGHT),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_FEAR),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_HALLUCINATION),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_CHARM),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_FLY),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_HUNGRY),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_STARVATION),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_FAINT),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_DRUNK),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_VANISH),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_IRON_BODY),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_PASSWALL),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_STAT_SENSE_INVISIBLE),
+	(abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RUN_AWAY),
+
+	/* ɲ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ⤭ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -142,13 +262,15 @@ move_kind_t	g_move_trans_tab[] = {
 	MOVE_KIND_STAGGER,	/* եĤ */
 	MOVE_KIND_WANDER,	/*  */
 	MOVE_KIND_TOWNER,	/* ν̱ */
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -198,16 +320,19 @@ act_kind_t	g_act_trans_tab[] = {
 	ACT_KIND_SRCH,
 	ACT_KIND_SPELL,
 
-	/* ѡƥΥ*/
+	/* ѡƥΥ */
 	ACT_KIND_SHOP,
 	ACT_KIND_RECALL,
+
+	/* ɲ */
+	ACT_KIND_TELEPORT_PARTY,
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * åȤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -227,13 +352,15 @@ trgt_kind_t	g_trgt_trans_tab[] = {
 	TRGT_KIND_SQUARE,
 	TRGT_KIND_POS,
 	TRGT_KIND_AUTO,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -245,13 +372,15 @@ dist_t	g_dist_trans_tab[] = {
 	DIST_NEAR,	/* ᤯ */
 	DIST_MEDIUM,	/*  */
 	DIST_FAR,	/*  */
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -267,13 +396,15 @@ auto_mark_trgt_t	g_am_trgt_trans_tab[] = {
 	AUTO_MARK_TRGT_MBR,
 	AUTO_MARK_TRGT_UNCHANGE,
 	AUTO_MARK_TRGT_CLEAR,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -285,13 +416,15 @@ auto_mark_dist_t	g_am_dist_trans_tab[] = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_DIST_MEDIUM,
 	AUTO_MARK_DIST_FAR,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -312,13 +445,15 @@ auto_mark_act_t	g_am_act_trans_tab[] = {
 	AUTO_MARK_ACT_DISARM,
 	AUTO_MARK_ACT_PEEP,
 	AUTO_MARK_ACT_CHK,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -356,13 +491,15 @@ auto_mark_cond_t	g_am_cond_trans_tab[] = {
 
 	/* ̤ */
 	AUTO_MARK_COND_UN_IDENTIFIED,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ⤭ǡμɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -376,13 +513,15 @@ move_ls_kind_t	g_move_ls_trans_tab[] = {
 
 	/* Сȯ */
 	MOVE_LS_KIND_NOT_FIND,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ١ȿɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -399,13 +538,15 @@ attitude_t	g_attitude_trans_tab[] = {
 	ATTITUDE_NEUTRAL,
 	/* ŨŪ */
 	ATTITUDE_ENEMY,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ƥɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -434,13 +575,15 @@ item_kind_t	g_item_trans_tab[] = {
 	ITEM_KIND_COIN,
 	ITEM_KIND_JUNK,
 	ITEM_KIND_BONE,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -542,17 +685,22 @@ wpn_kind_t	g_wpn_trans_tab[] = {
 	WPN_KIND_DARTS,
 	WPN_KIND_SHURIKEN,
 	WPN_KIND_BOOMERANG,
+
+/* ɲ */
+
 /* 󥰡(ƥե) */
 	WPN_KIND_EXCALIBUR,
 /* ᥤ */
 	WPN_KIND_NUNCHAKUS,
+/* ٥ */
+	WPN_KIND_WAKIZASHI,
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ݤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -567,13 +715,15 @@ bow_kind_t	g_bow_trans_tab[] = {
 	BOW_KIND_SLING,
 	BOW_KIND_BLOW_GUN,
 	BOW_KIND_DAGGER,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɶɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -634,13 +784,59 @@ armor_kind_t	g_armor_trans_tab[] = {
 /* ­(ƥե) */
 	ARMOR_KIND_SPEED_BOOTS,
 	ARMOR_KIND_SLOW_BOOTS,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
+* 
+*  RAF ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* RAF  WPN_RANDM_ART_KIND_NULL ǡ롣
+***************************************************************/
+
+wpn_randm_art_kind_t	g_wpn_randm_art_trans_tab[] = {
+	WPN_RANDM_ART_KIND_BANE,
+	WPN_RANDM_ART_KIND_KILLER,
+	WPN_RANDM_ART_KIND_SLAYER,
+	WPN_RANDM_ART_KIND_ADD_STAT,
+	WPN_RANDM_ART_KIND_DRAIN,
+
+	/* ɲ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
+* 
+*  RAF ɶɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* RAF ɶ ARMOR_RANDM_ART_KIND_NULL ǡ롣
+***************************************************************/
+
+armor_randm_art_kind_t	g_armor_randm_art_trans_tab[] = {
+	ARMOR_RANDM_ART_KIND_GUARD,
+	ARMOR_RANDM_ART_KIND_BLOCK,
+	ARMOR_RANDM_ART_KIND_PROTECT,
+	ARMOR_RANDM_ART_KIND_RESI_STAT,
+	ARMOR_RANDM_ART_KIND_HEALING,
+
+	/* ɲ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -719,13 +915,15 @@ potion_kind_t	g_potion_trans_tab[] = {
 	POTION_KIND_CURE_POISON,
 	POTION_KIND_CURE_STATUS,
 	POTION_KIND_DETECT_MNSTR,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ʪɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -756,6 +954,7 @@ scroll_kind_t	g_scroll_trans_tab[] = {
 	SCROLL_KIND_SUBSTITUTE,
 	SCROLL_KIND_BURNING_HANDS,
 	SCROLL_KIND_MIND_READING,
+
 /* ɲ */
 	SCROLL_KIND_IDENTIFY_ALL_ITEM,
 	SCROLL_KIND_RALLY,
@@ -766,7 +965,7 @@ scroll_kind_t	g_scroll_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -779,13 +978,15 @@ stick_kind_t	g_stick_trans_tab[] = {
 	STICK_KIND_WAND,
 	STICK_KIND_ROD,
 	STICK_KIND_STAFF,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -798,13 +999,15 @@ acce_kind_t	g_acce_trans_tab[] = {
 	ACCE_KIND_RING,
 	ACCE_KIND_AMULET,
 	ACCE_KIND_NECKLACE,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ؤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -833,13 +1036,15 @@ ring_kind_t	g_ring_trans_tab[] = {
 	RING_KIND_CURE_MP,
 	RING_KIND_DRAIN_HP,
 	RING_KIND_DRAIN_MP,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -865,13 +1070,15 @@ amulet_kind_t	g_amulet_trans_tab[] = {
 	AMULET_KIND_RESI_STAT_VANISH,
 	AMULET_KIND_RESI_STAT_IRON_BODY,
 	AMULET_KIND_RESI_STAT_PASSWALL,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ؤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -895,13 +1102,15 @@ necklace_kind_t	g_necklace_trans_tab[] = {
 	NECKLACE_KIND_CURSE_MIND,
 	NECKLACE_KIND_CURSE_ELEC,
 	NECKLACE_KIND_CURSE_POIS,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ڴɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -951,13 +1160,15 @@ inst_kind_t	g_inst_trans_tab[] = {
 	INST_KIND_BAGPIPE,
 	INST_KIND_HARMONICA,
 	INST_KIND_KAZOO,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -971,13 +1182,15 @@ anthology_kind_t	g_anthology_trans_tab[] = {
 	ANTHOLOGY_KIND_STRENGTHEN_ABL,
 	ANTHOLOGY_KIND_WEAKEN_ABL,
 	ANTHOLOGY_KIND_RESI_STAT,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -990,13 +1203,39 @@ light_kind_t	g_light_trans_tab[] = {
 	LIGHT_KIND_TORCH,
 	LIGHT_KIND_LANTERN,
 	LIGHT_KIND_LAMP,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
+* 
+* ƥɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ƥ STAR_DROP_KIND_ELEC ǡ롣
+***************************************************************/
+
+star_drop_kind_t	g_key_item_trans_tab[] = {
+	STAR_DROP_KIND_ELEC,
+	STAR_DROP_KIND_PHYS,
+	STAR_DROP_KIND_HEAT,
+	STAR_DROP_KIND_COLD,
+	STAR_DROP_KIND_MIND,
+	STAR_DROP_KIND_ACID,
+	STAR_DROP_KIND_POIS,
+
+	/* ɲ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ˾ߤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1010,13 +1249,15 @@ wish_level_t	g_wish_level_trans_tab[] = {
 	WISH_LEVEL_DAEMON,
 	WISH_LEVEL_DJINNI,
 	WISH_LEVEL_GOD,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1062,13 +1303,16 @@ food_kind_t	g_food_trans_tab[] = {
 	FOOD_KIND_CRAN_BERRY,
 	FOOD_KIND_RASP_BERRY,
 	FOOD_KIND_STRAW_BERRY,
+	FOOD_KIND_POTAGE,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1084,13 +1328,15 @@ tobacco_kind_t	g_tobacco_trans_tab[] = {
 	TOBACCO_KIND_SNUFF_TOBACCO,
 	TOBACCO_KIND_CHEWING_TOBACCO,
 	TOBACCO_KIND_ABSTAIN_GUM,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * Υ֥ɤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1166,13 +1412,15 @@ tobacco_brand_t	g_tobacco_brand_trans_tab[] = {
 
 	/* ABSTAIN GUM */
 	TOBACCO_BRAND_NICOTIME,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ѥפɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1185,13 +1433,15 @@ pipe_kind_t	g_pipe_trans_tab[] = {
 	PIPE_KIND_PIPE,
 	PIPE_KIND_KISEL,
 	PIPE_KIND_CIGARET_HOLDER,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * õƥɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1212,13 +1462,15 @@ rare_goods_kind_t	g_rare_goods_trans_tab[] = {
 	RARE_GOODS_KIND_CALL_OF_HADES,
 	RARE_GOODS_KIND_MEMORIES_OF_THE_GOLDEN_AGE,
 	RARE_GOODS_KIND_ISNT_REALIZED,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1231,13 +1483,15 @@ coin_kind_t	g_coin_trans_tab[] = {
 	COIN_KIND_GOLD,
 	COIN_KIND_SILVER,
 	COIN_KIND_COPPER,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ˡɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1444,6 +1698,7 @@ spell_kind_t	g_spell_trans_tab[] = {
 	SPELL_KIND_NOTHING,
 	SPELL_KIND_POLTERGEIST,
 	SPELL_KIND_ANC_MAX_N,
+
 /* ɲ */
 	SPELL_KIND_IDENTIFY_ALL_ITEM,
 	SPELL_KIND_SUMMON_BONE,
@@ -1454,7 +1709,7 @@ spell_kind_t	g_spell_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 󥹥ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1608,8 +1863,8 @@ mnstr_kind_t	g_mnstr_trans_tab[] = {
 	/*  */
 	MNSTR_KIND_IMP,
 	MNSTR_KIND_JACK_O_LANTERN,
-	MNSTR_KIND_LESSER_DEMON,
-	MNSTR_KIND_GREATER_DEMON,
+	MNSTR_KIND_LESSER_DAEMON,
+	MNSTR_KIND_GREATER_DAEMON,
 	/* ܥ */
 	MNSTR_KIND_GREAT_MINOTAUR,
 	MNSTR_KIND_HIGH_RE_HOO,
@@ -1617,13 +1872,19 @@ mnstr_kind_t	g_mnstr_trans_tab[] = {
 	MNSTR_KIND_BLACK_UNICORN,
 	MNSTR_KIND_VAMPIRE_LORD,
 	MNSTR_KIND_GIGANTIC_CENTIPEDE,
+
+	/* ɲ */
+	MNSTR_KIND_BILLION_ELEMENTAL,
+	MNSTR_KIND_CYBERN,
+	MNSTR_KIND_RELATIVISTIC_DAEMON,
+	MNSTR_KIND_ETERNAL_DRAGON,
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 櫤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1642,13 +1903,15 @@ trap_kind_t	g_trap_trans_tab[] = {
 	TRAP_KIND_PIT,
 	TRAP_KIND_CHUTE,
 	TRAP_KIND_SANCTUARY,
+
+	/* ɲ */
 };
 
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * եȤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1714,6 +1977,7 @@ fx_kind_t	g_fx_trans_tab[] = {
 	FX_KIND_STORE_LIGHT,
 	FX_KIND_COUNTER_MAGIC,
 	FX_KIND_POLYMORPH,
+
 /* ɲ */
 	FX_KIND_RALLY,
 	FX_KIND_IRON_MAN,
@@ -1723,7 +1987,7 @@ fx_kind_t	g_fx_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1740,6 +2004,8 @@ request_kind_t	g_request_trans_tab[] = {
 	REQUEST_KIND_EXTERMINATE,	/* 󥹥༣ */
 	REQUEST_KIND_REVENGE,	/* Ƥ */
 	REQUEST_KIND_WANTED_CRIMINAL,	/* ޶ */
+
+	/* ɲ */
 };
 
 #endif	/* GFILE_TAB_H */
