@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.209 2009/05/28 07:29:09 bowkenken Exp $
+* $Id: gfile.c,v 1.210 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -3612,3 +3612,11 @@ void	un_load_crypt_c( FILE *fp, long c )
 {
 	g_un_c = c;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gfile_c( void )
+{
+}
