@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-kind.h,v 1.8 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: mnstr-kind.h,v 1.14 2009/02/19 05:26:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_KIND_H
@@ -183,15 +183,24 @@ typedef enum {
 	MNSTR_KIND_JACK_O_LANTERN,
 	MNSTR_KIND_SUCCUBUS,
 	MNSTR_KIND_INCUBUS,
-	MNSTR_KIND_LESSER_DEMON,
-	MNSTR_KIND_GREATER_DEMON,
+	MNSTR_KIND_LESSER_DAEMON,
+	MNSTR_KIND_GREATER_DAEMON,
 	/* ܥ */
-	MNSTR_KIND_GREAT_MINOTAUR,
 	MNSTR_KIND_HIGH_RE_HOO,
+	MNSTR_KIND_GREAT_MINOTAUR,
+	MNSTR_KIND_BILLION_ELEMENTAL,
+	MNSTR_KIND_CYBERN,
+	MNSTR_KIND_GIGANTIC_CENTIPEDE,
 	MNSTR_KIND_MEDUSA_ZOMBIE,
 	MNSTR_KIND_BLACK_UNICORN,
 	MNSTR_KIND_VAMPIRE_LORD,
-	MNSTR_KIND_GIGANTIC_CENTIPEDE,
+	MNSTR_KIND_RELATIVISTIC_DAEMON,
+	MNSTR_KIND_ETERNAL_DRAGON,
+	/* 饹ܥ */
+	MNSTR_KIND_EXEL,
+	MNSTR_KIND_EXELER,
+	MNSTR_KIND_XEX,
+	MNSTR_KIND_XX,
 	/**/
 	MNSTR_KIND_MAX_N,
 } mnstr_kind_t;
@@ -211,6 +220,7 @@ typedef enum {
 
 #define	FACE_MJR_MNSTR_DRAGON	'D'
 
+#define	FACE_MNR_MNSTR_ETERNAL_DRAGON	'X'
 /* Ancient dragon */
 #define	FACE_MNR_MNSTR_A_GOLD_DRAGON	'G'	/* RESI_KIND_SLAS,· */
 #define	FACE_MNR_MNSTR_A_SILVER_DRAGON	'S'	/* RESI_KIND_KNOC, */
@@ -238,7 +248,7 @@ typedef enum {
 
 #define	FACE_MNR_MNSTR_PHOENIX	'x'
 #define	FACE_MNR_MNSTR_UNICORN	'u'
-#define	FACE_MNR_MNSTR_PEGASUS	'p'		/*@@@*/
+#define	FACE_MNR_MNSTR_PEGASUS	'g'		/*@@@*/
 #define	FACE_MNR_MNSTR_PYON_PYON	'p'
 
 /*  */
@@ -255,6 +265,7 @@ typedef enum {
 
 #define	FACE_MJR_MNSTR_ELEMENTAL	'E'
 
+#define	FACE_MNR_MNSTR_BILLION_ELEMENTAL	'B'
 #define	FACE_MNR_MNSTR_FIRE_ELEMENTAL	'f'
 #define	FACE_MNR_MNSTR_SALAMANDER	's'
 #define	FACE_MNR_MNSTR_WATER_ELEMENTAL	'w'
@@ -384,6 +395,7 @@ typedef enum {
 
 #define	FACE_MJR_MNSTR_MAGICAL	'M'
 
+#define	FACE_MNR_MNSTR_CYBERN	'C'
 #define	FACE_MNR_MNSTR_INVISIBLE_STALKER	'v'
 #define	FACE_MNR_MNSTR_GARGOYLE	'g'
 #define	FACE_MNR_MNSTR_MIMIC	'&'
@@ -457,11 +469,16 @@ typedef enum {
 
 #define	FACE_MJR_MNSTR_DEVIL	'X'
 
+#define	FACE_MNR_MNSTR_XX	'X'
+#define	FACE_MNR_MNSTR_XEX	'E'
+#define	FACE_MNR_MNSTR_EXELER	'R'
+#define	FACE_MNR_MNSTR_EXEL	'L'
+#define	FACE_MNR_MNSTR_RELATIVISTIC_DAEMON	'V'
 #define	FACE_MNR_MNSTR_IMP	'i'
 #define	FACE_MNR_MNSTR_JACK_O_LANTERN	'j'
 #define	FACE_MNR_MNSTR_MIND_FLAYER	'm'		/*@@@*/
 #define	FACE_MNR_MNSTR_BEHEMOTH	'b'		/*@@@*/
-#define	FACE_MNR_MNSTR_LESSER_DEMON	'd'		/*@@@*/
-#define	FACE_MNR_MNSTR_GREATER_DEMON	'D'		/*@@@*/
+#define	FACE_MNR_MNSTR_LESSER_DAEMON	'd'
+#define	FACE_MNR_MNSTR_GREATER_DAEMON	'D'
 
 #endif	/* MNSTR_KIND_H */
