@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.227 2009/07/02 22:29:45 bowkenken Exp $
+* $Id: mnstr.c,v 1.229 2009/07/23 15:54:39 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -830,6 +830,24 @@ void	act_phase_all_mnstr( void )
 	}
 }
 
+/***************************************************************
+* ƤΥ󥹥ԥե¹
+***************************************************************/
+
+void	dismissal_phase_all_mnstr( void )
+{
+	mnstr_t	*head, *p, *pp;
+
+	head = &mnstr_used;
+	for( p = head->next->next; p != NULL; p = p->next ){
+		pp = p->prev;
+		if( pp == head )
+			break;
+
+		dismissal_phase_chr( pp );
+	}
+}
+
 /***************************************************************
 * 󥹥ιư¹ԽΥޤǰưĴ٤
 * mnstr_t *p : 󥹥
@@ -1149,6 +1167,7 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 {
 	chr_t	*trgt;
+	act_kind_t	act_kind;
 	attack_t	*ls;
 	ratio_t	sum_bash, sum_throw, sum_spell, n;
 
@@ -1176,11 +1195,19 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 	n = randm( sum_bash + sum_throw + sum_spell );
 
 	if( n < sum_bash ){
-		set_chr_act( p, ACT_KIND_MBR_FIGHT,
-				trgt, NULL, 0, 0 );
+		if( is_mbr( trgt ) )
+			act_kind = ACT_KIND_MBR_FIGHT;
+		else
+			act_kind = ACT_KIND_MNSTR_FIGHT;
+
+		set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 	} else if( n < sum_bash + sum_throw ){
-		set_chr_act( p, ACT_KIND_MBR_THROW,
-				trgt, NULL, 0, 0 );
+		if( is_mbr( trgt ) )
+			act_kind = ACT_KIND_MBR_THROW;
+		else
+			act_kind = ACT_KIND_MNSTR_THROW;
+
+		set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 	} else {
 		attack_t	*atk;
 		long	d;
@@ -1195,33 +1222,35 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 		if( atk->kind == ATTACK_KIND_SPELL_SELF )
 			friend_chr = p;
 		else if( atk->kind == ATTACK_KIND_SPELL_FRIEND )
-			friend_chr = get_mnstr_randm( p->x, p->y );
+			friend_chr = get_mnstr_friend( p, p->x, p->y );
 		else
 			friend_chr = NULL;
 
 		if( friend_chr != NULL ){
 			rate_t	rate;
 
-			trgt = friend_chr;
 			rate = friend_chr->abl.hp.n * _100_PERCENT
 					/ friend_chr->abl.hp.max;
 			if( rate < 70 ){
+				trgt = friend_chr;
 				mark_mnstr( p, friend_chr, DIST_FAR );
 			} else {
-				set_chr_act( p, ACT_KIND_MBR_FIGHT,
-						trgt, NULL, 0, 0 );
-				return TRUE;
+				friend_chr = NULL;
 			}
 		}
 
-		if( chk_find_chr( p, trgt ) ){
+		if( (friend_chr != NULL) && chk_find_chr( p, friend_chr ) ){
 			set_chr_act( p, ACT_KIND_SPELL,
 					get_spell_tab( atk->spell ),
 					MSG( atk->spell_fmt ),
 					atk->extent, 0 );
 		} else {
-			set_chr_act( p, ACT_KIND_MBR_FIGHT,
-					trgt, NULL, 0, 0 );
+			if( is_mbr( trgt ) )
+				act_kind = ACT_KIND_MBR_FIGHT;
+			else
+				act_kind = ACT_KIND_MNSTR_FIGHT;
+
+			set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 		}
 	}
 
@@ -2782,7 +2811,7 @@ mnstr_t	*get_mnstr_mp_max( long x, long y )
 }
 
 /***************************************************************
-* 1  MP ¿󥹥򸡺
+* 1 (HP/MP)(¿/ʤ)󥹥򸡺
 * long x : X ɸ
 * long y : Y ɸ
 * return : 󥹥
@@ -2825,16 +2854,16 @@ mnstr_t	*get_mnstr_hp_mp_min_max(
 		else
 			tmp_n = pp->abl.mp.n;
 
-		if( (min_max >= +1) && (tmp_n > min_max_n) ){
-			min_max_n = tmp_n;
-			n = 0;
-		} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
-			min_max_n = tmp_n;
-			n = 0;
-		} else if( tmp_n == min_max_n ){
+		if( tmp_n == min_max_n ){
 			n++;
 			if( randm( n ) != 0 )
 				continue;
+		} else if( (min_max >= +1) && (tmp_n > min_max_n) ){
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
+			min_max_n = tmp_n;
+			n = 1;
 		} else {
 			continue;
 		}
@@ -2991,6 +3020,25 @@ mnstr_t	*get_mnstr_randm2( long x, long y )
 	return NULL;
 }
 
+/***************************************************************
+* 󥹥֤˸
+* mnstr_t *p : 󥹥
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+chr_t	*get_mnstr_friend( mnstr_t *p, long x, long y )
+{
+	if( p == NULL )
+		return get_mnstr_hp_min( x, y );
+
+	if( p->attitude == ATTITUDE_ENEMY )
+		return get_mnstr_hp_min( x, y );
+
+	return get_mbr_hp_min();
+}
+
 /***************************************************************
 * 󥹥δʸ򸡺
 * char mjr : ᥸㡼δʸ
