@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.44 2009/06/24 10:44:14 bowkenken Exp $
+* $Id: msg.c,v 1.47 2009/07/25 20:47:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -37,6 +37,12 @@
 
 /***************************************************************/
 
+#define	FLG_DFLT_ENGLISH	0
+
+/***************************************************************
+* ʸ
+***************************************************************/
+
 #define	STR_S	"%s"
 #define	STR_ENV_LANG	"LANG"
 #define	STR_SUPPORT_LANG	"Supporting languages are:"
@@ -69,16 +75,22 @@
 #define	LANG_TAB_MAX_N	64
 
 /* ǥեȤθ */
-#ifdef	D_DOS
+#if	FLG_DFLT_ENGLISH
+# define	STR_DFLT_LANG	"C"
+#elif	defined( D_DOS )
 # define	STR_DFLT_LANG	"ja_JP.SJIS"
+#elif	defined( D_GTK )
+# define	STR_DFLT_LANG	"ja_JP.UTF-8"
 #else
 # define	STR_DFLT_LANG	"ja_JP.eucJP"
 #endif
 
 /* μ */
 static lang_kind_t	g_lang_kind, g_lang_kind_next;
+check_memory_def( check_memory_msg_c_g_lang_kind )
 /* ͥ褹 */
 static bool_t	g_flg_lang_ls_priority;
+check_memory_def( check_memory_msg_c_g_flg_lang_ls_priority )
 
 /* Υǡ */
 typedef struct {
@@ -120,6 +132,7 @@ static lang_t	lang_tab[LANG_TAB_MAX_N] = {
 		LANG_KIND_MAX_N,
 	},
 };
+check_memory_def( check_memory_msg_c_lang_tab )
 
 /***************************************************************
 * å
@@ -135,6 +148,7 @@ typedef struct {
 /* åơ֥ */
 
 static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N];
+check_memory_def( check_memory_msg_c_all_lang_msg )
 
 /* ֥å 0 */
 
@@ -163,6 +177,7 @@ static msg_t	all_lang_msg_0[LANG_KIND_MAX_N]
 	},
 };
 #undef	SEL_MSG_BLOCK_0
+check_memory_def( check_memory_msg_c_all_lang_msg_0 )
 
 /* ֥å 1 */
 
@@ -191,9 +206,11 @@ static msg_t	all_lang_msg_1[LANG_KIND_MAX_N]
 	},
 };
 #undef	SEL_MSG_BLOCK_1
+check_memory_def( check_memory_msg_c_all_lang_msg_1 )
 
 /* åƤʤåѤΥǡ */
 static bool_t	flg_msg_def[N_MSG_MAX_N];
+check_memory_def( check_memory_msg_c_flg_msg_def )
 
 /***************************************************************
 * åν
@@ -209,10 +226,6 @@ void	init_msg( void )
 
 	flg_exit = FALSE;
 
-#ifdef	HAVE_LOCALE_H
-	setlocale( LC_ALL, "" );
-#endif
-
 	block_bgn_n = 0;
 	block_end_n = N_MSG__MSG_BLOCK_0_END_;
 	for( l = 0; l < LANG_KIND_MAX_N; l++ ){
@@ -241,9 +254,19 @@ void	init_msg( void )
 		lang = getenv( STR_ENV_LANG );
 		if( lang == NULL )
 			lang = STR_DFLT_LANG;
+#ifdef	D_GTK
+		lang = STR_DFLT_LANG;
+#endif
 	} else {
 		lang = g_language;
 	}
+#ifdef	HAVE_SETENV
+	setenv( STR_ENV_LANG, lang, 1 );
+#endif
+
+#ifdef	HAVE_LOCALE_H
+	setlocale( LC_ALL, "" );
+#endif
 
 	/* Ķѿǻꤵ줿μõ */
 
@@ -642,3 +665,24 @@ long	str_len_draw_japanese_sjis( const char *s )
 	return len;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_msg_c( void )
+{
+	check_memory( check_memory_msg_c_g_lang_kind,
+			"msg.c: g_lang_kind" );
+	check_memory( check_memory_msg_c_g_flg_lang_ls_priority,
+			"msg.c: g_flg_lang_ls_priority" );
+	check_memory( check_memory_msg_c_lang_tab,
+			"msg.c: lang_tab" );
+	check_memory( check_memory_msg_c_all_lang_msg,
+			"msg.c: all_lang_msg" );
+	check_memory( check_memory_msg_c_all_lang_msg_0,
+			"msg.c: all_lang_msg_0" );
+	check_memory( check_memory_msg_c_all_lang_msg_1,
+			"msg.c: all_lang_msg_1" );
+	check_memory( check_memory_msg_c_flg_msg_def,
+			"msg.c: flg_msg_def" );
+}
