@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.h,v 1.34 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: request.h,v 1.37 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	REQUEST_H
@@ -49,7 +49,9 @@
 #define	REQUEST_AVE_N	32
 
 /* åκĹ */
-#define	REQUEST_MSG_MAX_LEN	1024
+#define	REQUEST_MSG_MAX_LEN	4096
+#define	REQUEST_MSG_MAX_BYTE	\
+	(REQUEST_MSG_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /***************************************************************
 * μ
@@ -116,11 +118,11 @@ typedef struct request_t {
 	long	mnstr_exterminate_n;
 
 	/* ꥹȾθФ */
-	char	heading[MENU_MSG_MAX_LEN + 1];
+	char	heading[MENU_MSG_MAX_BYTE + 1];
 	/* åΥǥå */
 	n_msg_idx_t	idx_fmt;
 	/* å */
-	char	msg[REQUEST_MSG_MAX_LEN + 1];
+	char	msg[REQUEST_MSG_MAX_BYTE + 1];
 
 	/* ̾Υǥå */
 	n_msg_idx_t	idx_client_name;
