@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.149 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: tmenu.c,v 1.153 2009/07/12 05:41:25 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -61,21 +61,29 @@
 /**/
 
 static mbr_t	*g_sel_mbr, *g_sel_ls_mbr;
+check_memory_def( check_memory_tmenu_c_g_sel_mbr )
+
 static shop_n_t	g_shop_n;
 static deal_kind_t	g_deal_kind;
 static item_t	*g_sel_art;
 static long	g_sel_class_n;
+check_memory_def( check_memory_tmenu_c_g_shop_n )
+
 static item_t	*g_mbr_order[MBR_MAX_N];
+check_memory_def( check_memory_tmenu_c_g_mbr_order )
 
 static menu_t	*g_navi_dflt;
+check_memory_def( check_memory_tmenu_c_g_navi_dflt )
 
 /**/
 
 static edit_class_t	static_exec_edit_class__n;
 static edit_skill_t	static_exec_edit_skill__n;
+check_memory_def( check_memory_tmenu_c_static_exec_edit_class__n )
 
 skill_kind_t	g_sel_skill_kind;
 edit_skill_t	g_skill_slot_n;
+check_memory_def( check_memory_tmenu_c_g_sel_skill_kind  )
 
 /**/
 
@@ -2097,49 +2105,53 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_bar_arrange_up( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange_1( -1 );
+	menu_bar_arrange_1( g_sel_ls_mbr, -1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_down( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange_1( +1 );
+	menu_bar_arrange_1( g_sel_ls_mbr, +1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_top( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange( -1 );
+	menu_bar_arrange( g_sel_ls_mbr, -1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_bottom( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange( +1 );
+	menu_bar_arrange( g_sel_ls_mbr, +1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
-char	*cb_menu_bar_arrange_1( long d )
+void	menu_bar_arrange_1( mbr_t *mbr, long d )
 {
 	long	trgt_ls_mbr_n;
 	mbr_t	**ls_mbr, *tmp_mbr;
 
-	if( g_sel_ls_mbr == NULL )
-		return STR_MENU_ERR;
+	if( mbr == NULL )
+		return;
 
 	ls_mbr = get_ls_mbr();
-	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
+	trgt_ls_mbr_n = mbr->ls_mbr_n;
 	if( (trgt_ls_mbr_n + d) < 0 )
-		return "/bar/form/edit member/edit member";
+		return;
 	if( (trgt_ls_mbr_n + d) >= LS_MBR_MAX_N )
-		return "/bar/form/edit member/edit member";
+		return;
 	if( chk_flg( ls_mbr[trgt_ls_mbr_n + d]->stat,
 			FLG_STAT_NOT_EXIST ) ){
-		return "/bar/form/edit member/edit member";
+		return;
 	}
 
 	arrange_cast_tab_1( trgt_ls_mbr_n, d );
@@ -2158,29 +2170,28 @@ char	*cb_menu_bar_arrange_1( long d )
 	ls_mbr[trgt_ls_mbr_n + d]->ls_mbr_n = trgt_ls_mbr_n + d;
 
 	g_sel_ls_mbr = ls_mbr[0];
-	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
-char	*cb_menu_bar_arrange( long d )
+void	menu_bar_arrange( mbr_t *mbr, long d )
 {
 	long	trgt_ls_mbr_n;
 	mbr_t	**ls_mbr, *tmp_mbr;
 	long	i;
 
-	if( g_sel_ls_mbr == NULL )
-		return STR_MENU_ERR;
+	if( mbr == NULL )
+		return;
 
 	ls_mbr = get_ls_mbr();
-	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
+	trgt_ls_mbr_n = mbr->ls_mbr_n;
 
 	arrange_cast_tab( trgt_ls_mbr_n, d );
 	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
 	arrange_item( trgt_ls_mbr_n, d );
 	arrange_equip( trgt_ls_mbr_n, d );
 
-	tmp_mbr = g_sel_ls_mbr;
+	tmp_mbr = mbr;
 	if( d <= -1 ){
 		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
 			ls_mbr[i + 1] = ls_mbr[i];
@@ -2207,8 +2218,6 @@ char	*cb_menu_bar_arrange( long d )
 
 		g_sel_ls_mbr = ls_mbr[i - 1];
 	}
-
-	return "/bar/form/edit member/edit member";
 }
 
 /**/
@@ -2607,6 +2616,7 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 	edit_class_t	prev_n;
 	class_t	edit, *work;
 	bool_t	flg_sel_add;
+	bool_t	flg_sel;
 
 	n = static_exec_edit_class__n;
 
@@ -2633,6 +2643,8 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 
 		call_gui_class_edit_draw( work );
 
+		flg_sel = FALSE;
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 		case CASE_EXEC:
@@ -2644,38 +2656,13 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 			}
 			draw_edit_class_all( org, work, n, flg_sel_add );
 			break;
+		case ' ':
+			if( get_flg_space_select() )
+				flg_sel = TRUE;
+			break;
 		case CASE_ENTER:
-			if( n == EDIT_CLASS_NEXT ){
-				if( exec_menu_ask_edit_class(
-						org, work, flg_new ) ){
-					static_exec_edit_class__n = n;
-					return +1;
-				}
-				draw_edit_class_all( org, work, n,
-						flg_sel_add );
-				break;
-			} else if( n == EDIT_CLASS_PREV ){
-				if( exec_menu_ask_edit_class(
-						org, work, flg_new ) ){
-					static_exec_edit_class__n = n;
-					return -1;
-				}
-				draw_edit_class_all( org, work, n,
-						flg_sel_add );
-				break;
-			} else if( n == EDIT_CLASS_NAME ){
-				draw_edit_class( org, work, n,
-						FALSE, flg_sel_add );
-				gets_class_name( work->name );
-				break;
-			}
-
-			if( flg_sel_add )
-				menu_edit_class_inc_abl( work, n, +1 );
-			else
-				menu_edit_class_inc_abl( work, n, -1 );
-			draw_edit_class( org, work, EDIT_CLASS_TOTAL,
-					FALSE, flg_sel_add );
+			if( !get_flg_space_select() )
+				flg_sel = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 			flg_sel_add = TRUE;
@@ -2695,6 +2682,42 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		default:
 			break;
 		}
+
+		if( flg_sel ){
+			if( n == EDIT_CLASS_NEXT ){
+				if( exec_menu_ask_edit_class(
+						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
+					return +1;
+				}
+				draw_edit_class_all( org, work, n,
+						flg_sel_add );
+			} else if( n == EDIT_CLASS_PREV ){
+				if( exec_menu_ask_edit_class(
+						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
+					return -1;
+				}
+				draw_edit_class_all( org, work, n,
+						flg_sel_add );
+			} else if( n == EDIT_CLASS_NAME ){
+				draw_edit_class( org, work, n,
+						FALSE, flg_sel_add );
+				gets_class_name( work->name );
+			} else {
+				if( flg_sel_add ){
+					menu_edit_class_inc_abl(
+							work, n, +1 );
+				} else {
+					menu_edit_class_inc_abl(
+							work, n, -1 );
+				}
+
+				draw_edit_class( org, work,
+						EDIT_CLASS_TOTAL,
+						FALSE, flg_sel_add );
+			}
+		}
 	}
 
 	static_exec_edit_class__n = n;
@@ -2708,6 +2731,7 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 	edit_skill_t	*pn, prev_n;
 	class_t	edit, *work;
 	long	slot;
+	bool_t	flg_sel;
 
 	g_skill_slot_n = static_exec_edit_skill__n;
 
@@ -2734,6 +2758,8 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 
 		call_gui_skill_edit_draw( work );
 
+		flg_sel = FALSE;
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 		case CASE_EXEC:
@@ -2745,43 +2771,13 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 			}
 			draw_edit_skill_all( org, work, *pn );
 			break;
+		case ' ':
+			if( get_flg_space_select() )
+				flg_sel = TRUE;
+			break;
 		case CASE_ENTER:
-			if( *pn == EDIT_SKILL_NEXT ){
-				if( exec_menu_ask_edit_skill(
-						org, work, flg_new ) ){
-					static_exec_edit_skill__n = *pn;
-					return +1;
-				}
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( *pn == EDIT_SKILL_PREV ){
-				if( exec_menu_ask_edit_skill(
-						org, work, flg_new ) ){
-					static_exec_edit_skill__n = *pn;
-					return -1;
-				}
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
-				draw_edit_skill( org, work, *pn, FALSE );
-				gets_class_name( work->name );
-				break;
-			} else if( (EDIT_SKILL_A_00 <= *pn)
-					&& (*pn <= EDIT_SKILL_A_09) ){
-				slot = *pn - EDIT_SKILL_A_00;
-
-				exec_sel_skill_edit( work, slot );
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( (EDIT_SKILL_B_00 <= *pn)
-					&& (*pn <= EDIT_SKILL_B_09) ){
-				slot = *pn - EDIT_SKILL_B_00
-						+ SKILL_PER_PAGE_MAX_N;
-
-				exec_sel_skill_edit( work, slot );
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			}
+			if( !get_flg_space_select() )
+				flg_sel = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 		case CASE_CRSR_RIGHT:
@@ -2798,6 +2794,40 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 		default:
 			break;
 		}
+
+		if( flg_sel ){
+			if( *pn == EDIT_SKILL_NEXT ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return +1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+			} else if( *pn == EDIT_SKILL_PREV ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return -1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
+				draw_edit_skill( org, work, *pn, FALSE );
+				gets_class_name( work->name );
+			} else if( (EDIT_SKILL_A_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_A_09) ){
+				slot = *pn - EDIT_SKILL_A_00;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+			} else if( (EDIT_SKILL_B_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_B_09) ){
+				slot = *pn - EDIT_SKILL_B_00
+						+ SKILL_PER_PAGE_MAX_N;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+			}
+		}
 	}
 
 	static_exec_edit_skill__n = *pn;
@@ -3774,7 +3804,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	k = 0;
 	key = 'A';
 	n = 0;
-	max_n = PET_MAX_N;
+	max_n = LS_PET_MAX_N;
 
 	str_nz_cpy( ls[k].path, "/pet shop name", MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
@@ -4487,3 +4517,24 @@ void	set_cur_shop_n( shop_n_t n )
 
 /**/
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_tmenu_c( void )
+{
+	check_memory( check_memory_tmenu_c_g_sel_mbr,
+			"tmenu.c: g_sel_mbr" );
+	check_memory( check_memory_tmenu_c_g_shop_n,
+			"tmenu.c: g_shop_n" );
+	check_memory( check_memory_tmenu_c_g_mbr_order,
+			"tmenu.c: g_mbr_order" );
+	check_memory( check_memory_tmenu_c_g_navi_dflt,
+			"tmenu.c: g_navi_dflt" );
+	check_memory( check_memory_tmenu_c_static_exec_edit_class__n,
+			"tmenu.c: static_exec_edit_class__n" );
+	check_memory( check_memory_tmenu_c_g_sel_skill_kind,
+			"tmenu.c: g_sel_skill_kind" );
+}
+
+/**/
